from distutils.core import setup

setup(
      name           = 'westerLee111',
      version        = '1.0.0',
      py_modules     = ['westerLee111'],
      author         = 'jianyuanli',
      author_email    = '1302733407@qq.com',
      url            = 'https://pypi.org',
      description    = 'A simple printer of nested lists',
      )
